# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2017-2023, by Samuel Williams.

require 'rspec/files'

module Async
	module RSpec
		Leaks = ::RSpec::Files::Leaks
	end
end
