# frozen_string_literal: true

# Released under the MIT License.
# Copyright, 2018-2023, by Samuel Williams.
# Copyright, 2018, by Janko Marohnić.

require 'rspec/memory'

module Async
	module RSpec
		Memory = ::RSpec::Memory
	end
end
